@@ -41,6 +41,19 @@ var _ fi.CloudupModelBuilder = &VMScaleSetModelBuilder{}
 
 // Build is responsible for constructing the VM ScaleSet from the kops spec.
 func (b *VMScaleSetModelBuilder) Build(c *fi.CloudupModelBuilderContext) error {
+	c.AddTask(&azuretasks.ApplicationSecurityGroup{
+		Name:          fi.PtrTo(b.NameForApplicationSecurityGroupControlPlane()),
+		Lifecycle:     b.Lifecycle,
+		ResourceGroup: b.LinkToResourceGroup(),
+		Tags:          map[string]*string{},
+	})
+	c.AddTask(&azuretasks.ApplicationSecurityGroup{
+		Name:          fi.PtrTo(b.NameForApplicationSecurityGroupNodes()),
+		Lifecycle:     b.Lifecycle,
+		ResourceGroup: b.LinkToResourceGroup(),
+		Tags:          map[string]*string{},
+	})
+
 	for _, ig := range b.InstanceGroups {
 		name := b.AutoscalingGroupName(ig)
 		vmss, err := b.buildVMScaleSetTask(c, name, ig)
@@ -49,17 +62,19 @@ func (b *VMScaleSetModelBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 		}
 		c.AddTask(vmss)
 
-		// Create tasks for assigning built-in roles to VM Scale Sets.
-		// See https://docs.microsoft.com/en-us/azure/role-based-access-control/built-in-roles
-		// for the ID definitions.
-		roleDefIDs := map[string]string{
-			// Owner
-			"owner": "8e3af657-a8ff-443c-a75c-2fe8c4bcb635",
-			// Storage Blob Data Contributor
-			"blob": "ba92f5b4-2d11-453d-a403-e96b0029c9fe",
-		}
-		for k, roleDefID := range roleDefIDs {
-			c.AddTask(b.buildRoleAssignmentTask(vmss, k, roleDefID))
+		if ig.IsControlPlane() || b.Cluster.UsesLegacyGossip() {
+			// Create tasks for assigning built-in roles to VM Scale Sets.
+			// See https://docs.microsoft.com/en-us/azure/role-based-access-control/built-in-roles
+			// for the ID definitions.
+			roleDefIDs := map[string]string{
+				// Owner
+				"owner": "8e3af657-a8ff-443c-a75c-2fe8c4bcb635",
+				// Storage Blob Data Contributor
+				"blob": "ba92f5b4-2d11-453d-a403-e96b0029c9fe",
+			}
+			for k, roleDefID := range roleDefIDs {
+				c.AddTask(b.buildRoleAssignmentTask(vmss, k, roleDefID))
+			}
 		}
 	}
 
@@ -90,6 +105,15 @@ func (b *VMScaleSetModelBuilder) buildVMScaleSetTask(
 		Zones:              azNumbers,
 	}
 
+	switch ig.Spec.Role {
+	case kops.InstanceGroupRoleControlPlane:
+		t.ApplicationSecurityGroups = append(t.ApplicationSecurityGroups, b.LinkToApplicationSecurityGroupControlPlane())
+	case kops.InstanceGroupRoleNode:
+		t.ApplicationSecurityGroups = append(t.ApplicationSecurityGroups, b.LinkToApplicationSecurityGroupNodes())
+	default:
+		return nil, fmt.Errorf("unexpected instance group role for instance group: %q, %q", ig.Name, ig.Spec.Role)
+	}
+
 	var err error
 	if t.Capacity, err = getCapacity(&ig.Spec); err != nil {
 		return nil, err
@@ -192,9 +216,9 @@ func getStorageProfile(spec *kops.InstanceGroupSpec) (*compute.VirtualMachineSca
 	}
 
 	return &compute.VirtualMachineScaleSetStorageProfile{
-		ImageReference: imageReference,
+		DiskControllerType: fi.PtrTo(string(compute.SCSI)),
+		ImageReference:     imageReference,
 		OsDisk: &compute.VirtualMachineScaleSetOSDisk{
-			// TODO(kenji): Support Windows.
 			OsType:       compute.OperatingSystemTypes(compute.Linux),
 			CreateOption: compute.DiskCreateOptionTypesFromImage,
 			DiskSizeGB:   to.Int32Ptr(volumeSize),
