@@ -29,8 +29,9 @@ var _ iam.Subject = &ServiceAccount{}
 
 // BuildAWSPolicy generates a custom policy for a ServiceAccount IAM role.
 func (r *ServiceAccount) BuildAWSPolicy(b *iam.PolicyBuilder) (*iam.Policy, error) {
-	clusterName := b.Cluster.ObjectMeta.Name
-	p := iam.NewPolicy(clusterName, b.Partition)
+	p := &iam.Policy{
+		Version: iam.PolicyDefaultVersion,
+	}
 
 	iam.AddDNSControllerPermissions(b, p)
 
