@@ -43,7 +43,7 @@ func (b *NetworkingOptionsBuilder) BuildOptions(o interface{}) error {
 	if b.Context.IsKubernetesLT("1.24") {
 		if UsesCNI(networking) {
 			options.Kubelet.NetworkPluginName = fi.PtrTo("cni")
-		} else if networking.GCE != nil {
+		} else if networking.GCP != nil {
 			options.Kubelet.NetworkPluginName = fi.PtrTo("kubenet")
 		}
 	}
