@@ -25,7 +25,6 @@ import (
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -39,8 +38,8 @@ type IAMInstanceProfileRole struct {
 	Role            *IAMRole
 }
 
-func (e *IAMInstanceProfileRole) Find(c *fi.Context) (*IAMInstanceProfileRole, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *IAMInstanceProfileRole) Find(c *fi.CloudupContext) (*IAMInstanceProfileRole, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	if e.Role == nil || e.Role.ID == nil {
 		klog.V(2).Infof("Role/RoleID not set")
@@ -79,8 +78,8 @@ func (e *IAMInstanceProfileRole) Find(c *fi.Context) (*IAMInstanceProfileRole, e
 	return nil, nil
 }
 
-func (e *IAMInstanceProfileRole) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *IAMInstanceProfileRole) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *IAMInstanceProfileRole) CheckChanges(a, e, changes *IAMInstanceProfileRole) error {
@@ -125,18 +124,3 @@ func (_ *IAMInstanceProfileRole) RenderTerraform(t *terraform.TerraformTarget, a
 
 	return t.RenderResource("aws_iam_instance_profile", *e.InstanceProfile.Name, tf)
 }
-
-type cloudformationIAMInstanceProfile struct {
-	InstanceProfileName *string                   `json:"InstanceProfileName"`
-	Roles               []*cloudformation.Literal `json:"Roles"`
-	// TODO: Add tags when Cloudformation supports them
-}
-
-func (_ *IAMInstanceProfileRole) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *IAMInstanceProfileRole) error {
-	cf := &cloudformationIAMInstanceProfile{
-		InstanceProfileName: e.InstanceProfile.Name,
-		Roles:               []*cloudformation.Literal{e.Role.CloudformationLink()},
-	}
-
-	return t.RenderResource("AWS::IAM::InstanceProfile", *e.InstanceProfile.Name, cf)
-}
