@@ -17,7 +17,6 @@ limitations under the License.
 package awstasks
 
 import (
-	"errors"
 	"fmt"
 	"strings"
 
@@ -27,7 +26,6 @@ import (
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -52,8 +50,8 @@ func (e *IAMOIDCProvider) CompareWithID() *string {
 	return e.Name
 }
 
-func (e *IAMOIDCProvider) Find(c *fi.Context) (*IAMOIDCProvider, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *IAMOIDCProvider) Find(c *fi.CloudupContext) (*IAMOIDCProvider, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	response, err := cloud.IAM().ListOpenIDConnectProviders(&iam.ListOpenIDConnectProvidersInput{})
 	if err != nil {
@@ -75,7 +73,7 @@ func (e *IAMOIDCProvider) Find(c *fi.Context) (*IAMOIDCProvider, error) {
 			actualURL = "https://" + actualURL
 		}
 
-		if actualURL == fi.StringValue(e.URL) {
+		if actualURL == fi.ValueOf(e.URL) {
 
 			actual := &IAMOIDCProvider{
 				ClientIDs:   descResp.ClientIDList,
@@ -95,8 +93,8 @@ func (e *IAMOIDCProvider) Find(c *fi.Context) (*IAMOIDCProvider, error) {
 	return nil, nil
 }
 
-func (e *IAMOIDCProvider) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *IAMOIDCProvider) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *IAMOIDCProvider) CheckChanges(a, e, changes *IAMOIDCProvider) error {
@@ -139,7 +137,7 @@ func (p *IAMOIDCProvider) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *IAMOID
 		e.arn = response.OpenIDConnectProviderArn
 	} else {
 		if changes.Thumbprints != nil {
-			klog.V(2).Infof("Updating IAMOIDCProvider Thumbprints %q", fi.StringValue(e.arn))
+			klog.V(2).Infof("Updating IAMOIDCProvider Thumbprints %q", fi.ValueOf(e.arn))
 
 			request := &iam.UpdateOpenIDConnectProviderThumbprintInput{}
 			request.OpenIDConnectProviderArn = a.arn
@@ -247,7 +245,3 @@ func (p *IAMOIDCProvider) RenderTerraform(t *terraform.TerraformTarget, a, e, ch
 func (e *IAMOIDCProvider) TerraformLink() *terraformWriter.Literal {
 	return terraformWriter.LiteralProperty("aws_iam_openid_connect_provider", *e.Name, "arn")
 }
-
-func (_ *IAMOIDCProvider) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *IAMOIDCProvider) error {
-	return errors.New("cloudformation does not support IAM OIDC Provider")
-}
