@@ -28,7 +28,6 @@ import (
 	"k8s.io/kops/pkg/pki"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 )
 
@@ -47,13 +46,14 @@ type SSHKey struct {
 }
 
 var _ fi.CompareWithID = &SSHKey{}
+var _ fi.CloudupTaskNormalize = &SSHKey{}
 
 func (e *SSHKey) CompareWithID() *string {
 	return e.Name
 }
 
-func (e *SSHKey) Find(c *fi.Context) (*SSHKey, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *SSHKey) Find(c *fi.CloudupContext) (*SSHKey, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	return e.find(cloud)
 }
@@ -66,7 +66,7 @@ func (e *SSHKey) find(cloud awsup.AWSCloud) (*SSHKey, error) {
 	response, err := cloud.EC2().DescribeKeyPairs(request)
 	if awsErr, ok := err.(awserr.Error); ok {
 		if awsErr.Code() == "InvalidKeyPair.NotFound" {
-			return nil, nil
+			err = nil
 		}
 	}
 	if err != nil {
@@ -74,6 +74,9 @@ func (e *SSHKey) find(cloud awsup.AWSCloud) (*SSHKey, error) {
 	}
 
 	if response == nil || len(response.KeyPairs) == 0 {
+		if e.IsExistingKey() && *e.Name != "" {
+			return nil, fmt.Errorf("unable to find specified SSH key %q", *e.Name)
+		}
 		return nil, nil
 	}
 
@@ -91,28 +94,33 @@ func (e *SSHKey) find(cloud awsup.AWSCloud) (*SSHKey, error) {
 	}
 
 	// Avoid spurious changes
-	if fi.StringValue(k.KeyType) == ec2.KeyTypeEd25519 {
+	if fi.ValueOf(k.KeyType) == ec2.KeyTypeEd25519 {
 		// Trim the trailing "=" and prefix with "SHA256:" to match the output of "ssh-keygen -lf"
-		fingerprint := fi.StringValue(k.KeyFingerprint)
+		fingerprint := fi.ValueOf(k.KeyFingerprint)
 		fingerprint = strings.TrimRight(fingerprint, "=")
 		fingerprint = fmt.Sprintf("SHA256:%s", fingerprint)
-		actual.KeyFingerprint = fi.String(fingerprint)
+		actual.KeyFingerprint = fi.PtrTo(fingerprint)
 	}
-	if fi.StringValue(actual.KeyFingerprint) == fi.StringValue(e.KeyFingerprint) {
+	if fi.ValueOf(actual.KeyFingerprint) == fi.ValueOf(e.KeyFingerprint) {
 		klog.V(2).Infof("SSH key fingerprints match; assuming public keys match")
 		actual.PublicKey = e.PublicKey
 	} else {
-		klog.V(2).Infof("Computed SSH key fingerprint mismatch: %q %q", fi.StringValue(e.KeyFingerprint), fi.StringValue(actual.KeyFingerprint))
+		klog.V(2).Infof("Computed SSH key fingerprint mismatch: %q %q", fi.ValueOf(e.KeyFingerprint), fi.ValueOf(actual.KeyFingerprint))
 	}
 	actual.Lifecycle = e.Lifecycle
 	if actual.Shared {
 		// Don't report tag changes on shared keys
 		actual.Tags = e.Tags
 	}
+
+	e.ID = actual.ID
+	if e.IsExistingKey() && *e.Name != "" {
+		e.KeyFingerprint = actual.KeyFingerprint
+	}
 	return actual, nil
 }
 
-func (e *SSHKey) Run(c *fi.Context) error {
+func (e *SSHKey) Normalize(c *fi.CloudupContext) error {
 	if e.KeyFingerprint == nil && e.PublicKey != nil {
 		publicKey, err := fi.ResourceAsString(e.PublicKey)
 		if err != nil {
@@ -126,20 +134,12 @@ func (e *SSHKey) Run(c *fi.Context) error {
 		klog.V(2).Infof("Computed SSH key fingerprint as %q", keyFingerprint)
 		e.KeyFingerprint = &keyFingerprint
 	}
-	a, err := e.Find(c)
-	if err != nil {
-		return err
-	}
-	if e.IsExistingKey() && *e.Name != "" {
-		if a == nil {
-			return fmt.Errorf("unable to find specified SSH key %q", *e.Name)
-		}
-		e.KeyFingerprint = a.KeyFingerprint
-	}
-	if a != nil {
-		e.ID = a.ID
-	}
-	return fi.DefaultDeltaRunMethod(e, c)
+
+	return nil
+}
+
+func (e *SSHKey) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *SSHKey) CheckChanges(a, e, changes *SSHKey) error {
@@ -232,30 +232,6 @@ func (e *SSHKey) TerraformLink() *terraformWriter.Literal {
 	return terraformWriter.LiteralProperty("aws_key_pair", tfName, "id")
 }
 
-func (_ *SSHKey) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *SSHKey) error {
-	if e.NoSSHKey() {
-		return nil
-	}
-
-	cloud := t.Cloud.(awsup.AWSCloud)
-
-	klog.Warningf("Cloudformation does not manage SSH keys; pre-creating SSH key")
-
-	keypair, err := e.find(cloud)
-	if err != nil {
-		return err
-	}
-
-	if keypair == nil {
-		err := e.createKeypair(cloud)
-		if err != nil {
-			return err
-		}
-	}
-
-	return nil
-}
-
 func (e *SSHKey) NoSSHKey() bool {
 	return e.ID == nil && e.Name == nil && e.PublicKey == nil && e.KeyFingerprint == nil
 }
